Documentation
¶
Index ¶
- func AddCommands(rootCmd *cobra.Command, opts StartOptions, appExport types.AppExporter, ...)
- func ConnectTmWS(tmRPCAddr, tmEndpoint string, logger tmlog.Logger) *rpcclient.WSClient
- func Listen(addr string, config *config.Config) (net.Listener, error)
- func MountGRPCWebServices(router *mux.Router, grpcWeb *grpcweb.WrappedGrpcServer, grpcResources []string, ...)
- func StartCmd(opts StartOptions) *cobra.Command
- func StartJSONRPC(ctx *server.Context, clientCtx client.Context, tmRPCAddr, tmEndpoint string, ...) (*http.Server, chan struct{}, error)
- type DBOpener
- type StartOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddCommands ¶
func AddCommands( rootCmd *cobra.Command, opts StartOptions, appExport types.AppExporter, addStartFlags types.ModuleInitFlags, )
AddCommands adds server commands
func ConnectTmWS ¶
func Listen ¶
Listen starts a net.Listener on the tcp network on the given address. If there is a specified MaxOpenConnections in the config, it will also set the limitListener.
func MountGRPCWebServices ¶
func StartCmd ¶
func StartCmd(opts StartOptions) *cobra.Command
StartCmd runs the service passed in, either stand-alone or in-process with Tendermint.
Types ¶
type DBOpener ¶
type DBOpener func(opts types.AppOptions, rootDir string, backend dbm.BackendType) (dbm.DB, error)
DBOpener is a function to open `application.db`, potentially with customized options.
type StartOptions ¶
type StartOptions struct {
AppCreator types.AppCreator
DefaultNodeHome string
DBOpener DBOpener
}
StartOptions defines options that can be customized in `StartCmd`
func NewDefaultStartOptions ¶
func NewDefaultStartOptions(appCreator types.AppCreator, defaultNodeHome string) StartOptions
NewDefaultStartOptions use the default db opener provided in tm-db.
Click to show internal directories.
Click to hide internal directories.