Documentation
¶
Index ¶
- Variables
- type KVIndexer
- func (kv *KVIndexer) Close()
- func (kv *KVIndexer) GetByBlockAndIndex(blockNumber int64, txIndex uint) (*bbtypes.TxResult, error)
- func (kv *KVIndexer) GetByTxHash(hash common.Hash) (*bbtypes.TxResult, error)
- func (kv *KVIndexer) SetBlockAndIndex(blockNumber int64, txIndex uint, txRes *bbtypes.TxResult) error
- func (kv *KVIndexer) SetTxHash(hash common.Hash, txRes *bbtypes.TxResult) error
Constants ¶
This section is empty.
Variables ¶
var ErrorTxNotFound = errors.New("tx not found")
Functions ¶
This section is empty.
Types ¶
type KVIndexer ¶
type KVIndexer struct {
// contains filtered or unexported fields
}
KVIndexer implements a eth tx indexer on a KV db.
func NewKVIndexer ¶
NewKVIndexer creates the KVIndexer with a specified cache size
func (*KVIndexer) GetByBlockAndIndex ¶
GetByBlockAndIndex retrieves a transaction result by block number and transaction index
func (*KVIndexer) GetByTxHash ¶
GetByTxHash retrieves a transaction result by its hash
Click to show internal directories.
Click to hide internal directories.